4.16. umbra.components.factory.scriptEditor.editorStatus — Umbra 1.0.9 documentation

# 4.16. umbra.components.factory.scriptEditor.editorStatus

editorStatus.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `EditorStatus` class.

Others:

## 4.16.1. Module Attributes

`umbra.components.factory.scriptEditor.editorStatus.` `LOGGER`

`umbra.components.factory.scriptEditor.editorStatus.` `UI_FILE`

## 4.16.2. Classes

class `umbra.components.factory.scriptEditor.editorStatus.` `EditorStatus`(parent, *args, **kwargs)

  Bases: `foundations.ui.common.QWidget`

  Defines the `umbra.components.factory.scriptEditor.scriptEditor.ScriptEditor` Component Interface class status bar widget.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `container`

    Property for self.__container attribute.

    Returns: | self.__container.
    Return type: | QObject

  `Lines_Columns_label_defaultText`

    Property for self.__Lines_Columns_label_defaultText attribute.

    Returns: | self.__Lines_Columns_label_defaultText.
    Return type: | unicode